"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _ = _interopRequireDefault(require(".."));

var _getAssignFieldsData = _interopRequireDefault(require("../../helpers/getAssignFieldsData"));

var _table = _interopRequireDefault(require("../../styled/table"));

jest.mock('../../helpers/getAssignFieldsData', function () {
  return jest.fn(function () {
    return [{
      required: true,
      fileField: undefined,
      databaseField: 'name'
    }, {
      required: false,
      fileField: undefined,
      databaseField: 'age'
    }];
  });
});
var baseParams = {
  data: [{
    Name: 'John',
    Age: 25
  }, {
    Name: 'Marie',
    Age: 30
  }],
  attributes: {
    name: {
      required: true
    },
    age: {}
  },
  columns: ['Name', 'Age'],
  fieldsMap: {
    name: 'Name',
    age: 'Age'
  }
};
describe('<StepThree />', function () {
  it('should have the assign field modal closed by default', function () {
    var component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], baseParams));
    expect(component.find('AssignFieldModal').prop('isAssignFieldModalOpen')).toBe(false);
  });
  it('should pass params to modal', function () {
    var component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], baseParams));
    expect(component.find('AssignFieldModal').props()).toEqual(expect.objectContaining({
      data: [{
        Name: 'John',
        Age: 25
      }, {
        Name: 'Marie',
        Age: 30
      }],
      attributes: {
        name: {
          required: true
        },
        age: {}
      },
      columns: ['Name', 'Age'],
      fieldsMap: {
        name: 'Name',
        age: 'Age'
      }
    }));
  });
  it('should call getAssignFieldsData with the right data', function () {
    (0, _enzyme.mount)(_react["default"].createElement(_["default"], (0, _extends2["default"])({}, baseParams, {
      matchField: ""
    })));
    expect(_getAssignFieldsData["default"]).toHaveBeenCalledWith({
      fieldsMap: {
        name: 'Name',
        age: 'Age'
      },
      attributes: {
        name: {
          required: true
        },
        age: {}
      },
      matchField: ''
    });
  });
  it('should pass only the first three elements of data prop to AssignFieldModal', function () {
    baseParams.data = [{
      First_Name: 'John',
      Last_Name: 'Doe',
      Age: 27
    }, {
      First_Name: 'Marie',
      Last_Name: 'Doe',
      Age: 28
    }, {
      First_Name: 'Sophia',
      Last_Name: 'Doe',
      Age: 29
    }, {
      First_Name: 'Joseph',
      Last_Name: 'Doe',
      Age: 30
    }];
    var component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], baseParams));
    expect(component.find('AssignFieldModal').prop('data')).toEqual([{
      First_Name: 'John',
      Last_Name: 'Doe',
      Age: 27
    }, {
      First_Name: 'Marie',
      Last_Name: 'Doe',
      Age: 28
    }, {
      First_Name: 'Sophia',
      Last_Name: 'Doe',
      Age: 29
    }]);
  });
  it('should pass the right data to the Table component', function () {
    var component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], baseParams));
    expect(component.find(_table["default"]).prop('data')).toEqual([{
      required: true,
      fileField: undefined,
      databaseField: 'name'
    }, {
      required: false,
      fileField: undefined,
      databaseField: 'age'
    }]);
  });
  it('should open the modal when a column cell is clicked', function () {
    var component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], baseParams));
    component.find('ModifyCell').at(0).simulate('click');
    expect(component.find('AssignFieldModal').prop('isAssignFieldModalOpen')).toBe(true);
  });
  it('should close AssignFieldModal when onRequestClose prop is called', function () {
    var component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], baseParams));
    component.find('ModifyCell').at(0).simulate('click');
    component.find('AssignFieldModalFooter').find('Button').at(0).simulate('click');
    expect(component.find('AssignFieldModal').prop('isAssignFieldModalOpen')).toBe(false);
  });
  it('should pass the right databaseFieldToAssign prop to the modal when a column cell is clicked', function () {
    var component = (0, _enzyme.mount)(_react["default"].createElement(_["default"], baseParams));
    component.find('ModifyCell').at(1).simulate('click');
    expect(component.find('AssignFieldModal').prop('databaseFieldToAssign')).toBe('age');
  });
});