import React from 'react';
import { mount } from 'enzyme';
import VisualPicker from '../index';
import VisualPickerOption from '../../VisualPickerOption';
describe('<VisualPicker/>', function () {
  it('should call onChanged with string value', function () {
    var onChangeFn = jest.fn();
    var component = mount(React.createElement(VisualPicker, {
      onChange: onChangeFn
    }, React.createElement(VisualPickerOption, {
      name: "option1"
    }), React.createElement(VisualPickerOption, {
      name: "option2"
    }), React.createElement(VisualPickerOption, {
      name: "option3"
    })));
    component.find('VisualPickerOption[name="option2"]').find('input').simulate('change');
    expect(onChangeFn).toHaveBeenCalledWith('option2');
  });
  it('should call onChanged with array of names', function () {
    var onChangeFn = jest.fn();
    var component = mount(React.createElement(VisualPicker, {
      onChange: onChangeFn,
      multiple: true,
      value: ['option1']
    }, React.createElement(VisualPickerOption, {
      name: "option1"
    }), React.createElement(VisualPickerOption, {
      name: "option2"
    }), React.createElement(VisualPickerOption, {
      name: "option3"
    })));
    component.find('VisualPickerOption[name="option3"]').find('input[type="checkbox"]').simulate('change', {
      target: {
        checked: true
      }
    });
    expect(onChangeFn).toHaveBeenCalledWith(['option1', 'option3']);
  });
  it('should call onChanged with the new option selected when have it has one selected initially', function () {
    var onChangeFn = jest.fn();
    var component = mount(React.createElement(VisualPicker, {
      onChange: onChangeFn,
      value: "option1"
    }, React.createElement(VisualPickerOption, {
      name: "option1"
    }), React.createElement(VisualPickerOption, {
      name: "option2"
    }), React.createElement(VisualPickerOption, {
      name: "option3"
    })));
    component.find('VisualPickerOption[name="option3"]').find('input[type="radio"]').simulate('change');
    expect(onChangeFn).toHaveBeenCalledWith('option3');
  });
  it('should call onChanged with the right options when is multiple and the initial value is not an array', function () {
    var onChangeFn = jest.fn();
    var component = mount(React.createElement(VisualPicker, {
      onChange: onChangeFn,
      multiple: true,
      value: undefined
    }, React.createElement(VisualPickerOption, {
      name: "option1"
    }), React.createElement(VisualPickerOption, {
      name: "option2"
    }), React.createElement(VisualPickerOption, {
      name: "option3"
    })));
    component.find('VisualPickerOption[name="option3"]').find('input[type="checkbox"]').simulate('change', {
      target: {
        checked: true
      }
    });
    expect(onChangeFn).toHaveBeenCalledWith(['option3']);
  });
  it('should call onChanged with the right options when is multiple, have values selected initially and deselect one', function () {
    var onChangeFn = jest.fn();
    var component = mount(React.createElement(VisualPicker, {
      onChange: onChangeFn,
      multiple: true,
      value: ['option1', 'option3']
    }, React.createElement(VisualPickerOption, {
      name: "option1"
    }), React.createElement(VisualPickerOption, {
      name: "option2"
    }), React.createElement(VisualPickerOption, {
      name: "option3"
    })));
    component.find('VisualPickerOption[name="option3"]').find('input[type="checkbox"]').simulate('change', {
      target: {
        checked: false
      }
    });
    expect(onChangeFn).toHaveBeenCalledWith(['option1']);
  });
  it('should pass the right props to the Label component', function () {
    var component = mount(React.createElement(VisualPicker, {
      label: "custom label",
      required: true
    }));
    expect(component.find('Label').props()).toEqual({
      label: 'custom label',
      required: true,
      readOnly: false,
      labelAlignment: 'center',
      hideLabel: false,
      as: 'legend',
      variant: 'default',
      size: 'medium'
    });
  });
});